intelmq.tests.bots.collectors.microsoft package
===============================================

Submodules
----------

intelmq.tests.bots.collectors.microsoft.test\_collector\_azure module
---------------------------------------------------------------------

.. automodule:: intelmq.tests.bots.collectors.microsoft.test_collector_azure
   :members:
   :undoc-members:
   :show-inheritance:

intelmq.tests.bots.collectors.microsoft.test\_collector\_interflow module
-------------------------------------------------------------------------

.. automodule:: intelmq.tests.bots.collectors.microsoft.test_collector_interflow
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: intelmq.tests.bots.collectors.microsoft
   :members:
   :undoc-members:
   :show-inheritance:
